# encoding: utf-8
require 'spec_helper'

describe SPS::CreditorAccount do
  it 'should initialize a new account' do
    expect(
      SPS::CreditorAccount.new(
        name:                'Gläubiger GmbH',
        bic:                 'BANKDEFFXXX',
        iban:                'DE87200500001234567890',
        creditor_identifier: 'DE98ZZZ09999999999'
      )
    ).to be_valid
  end

  describe :creditor_identifier do
    it 'should accept valid value' do
      expect(SPS::CreditorAccount)
        .to accept(
          'DE98ZZZ09999999999',
          'AT12ZZZ00000000001',
          'IT97ZZZA1B2C3D4E5F6G7H8',
          'NL97ZZZ123456780001',
          'FR12ZZZ123456',
          for: :creditor_identifier
        )
    end

    it 'should not accept invalid value' do
      expect(SPS::CreditorAccount)
        .not_to accept(
          '',
          'invalid',
          'DE98ZZZ099999999990',
          'DEAAAAAAAAAAAAAAAA',
          for: :creditor_identifier
        )
    end
  end

  describe :isr_participant_number do
    it 'should accept valid value' do
      expect(SPS::CreditorAccount)
        .to accept('123123123', '554544543', nil, for: :isr_participant_number)
    end

    it 'should not accept invalid value' do
      expect(SPS::CreditorAccount)
        .not_to accept('32423432', 'a89898989', for: :isr_participant_number)
    end
  end
end
